@@ -21,36 +21,21 @@ import gobject
 import wave
 import array
 import Numeric
-import numpy
 import threading
 import time
 import datetime
+import pydrumbase
 
+from pydrumaccel import *
+from pydrumkeyboard import *
 from pymixer import *
 
 gobject.threads_init()
 
 bpp=16
 playsounds=True
-busychannels=[False,False,False,False,False,False,False,False]
-
-#f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", "r")
-
-import dbus
-bus = dbus.SystemBus()             
-accel = bus.get_object('com.nokia.mce',
-        '/com/nokia/mce/request',
-        'com.nokia.mce.request') 
-
-def dbusgetrotation():
-    orientation , stand , face , x , y , z = accel.get_device_orientation()
-    return (x,y,z)
-
-def getrotation():
-    f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", "r")
-    coords = [int(w) for w in f.readline().split()]
-    f.close()
-    return coords
+#busychannels=[False,False,False,False,False,False,False,False]
+            
 
 def main():
     global drumsound
@@ -60,12 +45,13 @@ def main():
     appdir =os.path.abspath(appdir)
     print "PATH: " + appdir
     pygame.init()
+    pygame.display.set_caption('Take it away Marco')
+
     pygame.mouse.set_visible(False)
 
     flags=0 
 #    flags=FULLSCREEN
     screen=pygame.display.set_mode((800,480),flags,bpp)
-    pygame.display.set_caption('Take it away Marco')
     print pygame.display.get_driver()
     print pygame.display.get_surface()
 
@@ -78,7 +64,6 @@ def main():
         mixer.addwav(appdir +"/sounds/TomTomDrums/tomtomdrum" +str(i) + ".wav")
         mixer.addwav(appdir +"/sounds/BassDrums1/bassdrum" +str(i) + ".wav")
 
-
     play(screen,mixer)
 
 def playsound (mixer, num):
@@ -104,7 +89,6 @@ def play(screen,mixer):
         for j in range(6):
             pygame.draw.rect(screen, (127,127,200),(550+(80*i),5 +(70*j),70,60))    
 
-
     font = pygame.font.Font(None, 48)
     text = font.render('Accelerometer', True, (64,64,64), (0,0,0))        
     text.set_colorkey((0,0,0))
@@ -112,6 +96,13 @@ def play(screen,mixer):
     screen.blit(text,textRect)
 
     pygame.display.flip()
+
+    accelaudioevent = AccelAudioEvent()
+    accelaudioevent.active = False
+
+    pgkeyaudioevent = PGKeyAudioEvent()
+    pgkeyaudioevent.active = True
+
     mixer.init_audio()
     active=True
     playaccel=False
@@ -122,34 +113,38 @@ def play(screen,mixer):
     cords2 = (0,0,0)
     busychannels=[0,0,0,0,0,0,0,0] 
 
+    audioevents = [accelaudioevent,pgkeyaudioevent]
+
     lastplayed=[0,0,0]
     run = 0
     tps = 200
     t1 = datetime.datetime.utcnow()
-    while True:        
+    while True:
+        run +=1        
         clock.tick(tps)
-        run += 1 
-
+ 
         for i in range(0,8):
             busychannels[i] = busychannels[i] -1
 
         for event in pygame.event.get():
+
+            for ae in audioevents:
+                ae.handleevent(event)
+
             if event.type == QUIT:
                 print str(t1.ctime())
                 print str(datetime.datetime.utcnow().ctime())
                 print "run " + str(run) + " times"               
                 mixer.endgracefully                
                 return False
-            if event.type == MOUSEBUTTONDOWN:
-                
-#                for i in range(4):
-#                    print str(textRect[i])
 
+            elif event.type == MOUSEBUTTONDOWN:
                 if (event.pos[0] >= textRect.x):
                   if (event.pos[0] <= textRect.x +textRect.width):
                     if (event.pos[1] >= textRect.top ): 
                      if (event.pos[1] <= textRect.top + textRect.height):
                         playaccel= not playaccel
+                        accelaudioevent.active = playaccel
 
                         if playaccel:
                             clr = (255,255,255)
@@ -166,8 +161,8 @@ def play(screen,mixer):
                 snds = getpossounds(event)
                 for snd in snds:
                     playsound(mixer,snd)
-            if event.type == KEYDOWN:
-                    playsound(mixer,0)
+
+#            elif event.type == KEYDOWN:
 
             elif event.type == pygame.ACTIVEEVENT:
                 print "Active changed"
@@ -180,21 +175,13 @@ def play(screen,mixer):
                     mixer.play()
                     active=False
 
-        if playaccel:
-            cords3 = getrotation()
-            for axis in range(0, 3):
-                if abs(cords3[axis] - cords2[axis]) > 100:
-                    if (lastplayed[axis] < run -10):
-                        lastplayed[axis] = run
-                        if playaccel:    
-                            if cords3[axis] > cords2[axis]:
-                                mixer.playsound(axis+3)
-                            else:
-                                mixer.playsound(axis)
-                            pass            
-            cords1=cords2            
-            cords2=cords3    
-    
+        for ae in audioevents:
+            if ae.active:
+                playarray = ae.process()
+                for j in range(len(playarray)):
+                    playsound(mixer,playarray[j])
+
+   
         mixer.process()
 
 
